@@ -2,44 +2,22 @@ package tim.prune;
 
 import tim.prune.correlate.AudioCorrelator;
 import tim.prune.correlate.PhotoCorrelator;
-import tim.prune.function.AboutScreen;
 import tim.prune.function.AddAltitudeOffset;
 import tim.prune.function.AddTimeOffset;
-import tim.prune.function.CheckVersionScreen;
-import tim.prune.function.ConnectToPointFunction;
-import tim.prune.function.ConvertNamesToTimes;
 import tim.prune.function.CreateMarkerWaypointsFunction;
 import tim.prune.function.CropToSelection;
+import tim.prune.function.DedupeWaypointsFunction;
 import tim.prune.function.DeleteFieldValues;
 import tim.prune.function.DeleteSelectedRangeFunction;
-import tim.prune.function.DisconnectAudioFunction;
-import tim.prune.function.DisconnectPhotoFunction;
-import tim.prune.function.DiskCacheConfig;
-import tim.prune.function.DownloadOsmFunction;
 import tim.prune.function.DuplicatePoint;
-import tim.prune.function.FindWaypoint;
-import tim.prune.function.GetWikipediaFunction;
-import tim.prune.function.HelpScreen;
-import tim.prune.function.IgnoreExifThumb;
 import tim.prune.function.InterpolateFunction;
-import tim.prune.function.PhotoPopupFunction;
-import tim.prune.function.PlayAudioFunction;
 import tim.prune.function.ProjectCircle;
 import tim.prune.function.ProjectPoint;
 import tim.prune.function.RearrangePhotosFunction;
 import tim.prune.function.RearrangeWaypointsFunction;
-import tim.prune.function.RemoveAudioFunction;
-import tim.prune.function.RemovePhotoFunction;
-import tim.prune.function.RotatePhoto;
-import tim.prune.function.SearchOsmPoisFunction;
-import tim.prune.function.SearchWikipediaNames;
 import tim.prune.function.SelectSegmentFunction;
-import tim.prune.function.SelectTimezoneFunction;
-import tim.prune.function.ShowFullDetails;
-import tim.prune.function.ShowKeysScreen;
 import tim.prune.function.ShowThreeDFunction;
 import tim.prune.function.SingleNumericParameterFunction;
-import tim.prune.function.StopAudioFunction;
 import tim.prune.function.autoplay.AutoplayFunction;
 import tim.prune.function.charts.Charter;
 import tim.prune.function.compress.CompressTrackFunction;
@@ -53,9 +31,29 @@ import tim.prune.function.edit.ToggleSegmentFlag;
 import tim.prune.function.edit.TruncatePointCoords;
 import tim.prune.function.estimate.EstimateTime;
 import tim.prune.function.estimate.LearnParameters;
+import tim.prune.function.info.AboutScreen;
+import tim.prune.function.info.CheckVersionScreen;
+import tim.prune.function.info.FindWaypoint;
+import tim.prune.function.info.HelpScreen;
+import tim.prune.function.info.ShowFullDetails;
+import tim.prune.function.info.ShowKeysScreen;
+import tim.prune.function.media.ConnectToPointFunction;
+import tim.prune.function.media.DisconnectAudioFunction;
+import tim.prune.function.media.DisconnectPhotoFunction;
+import tim.prune.function.media.IgnoreExifThumb;
+import tim.prune.function.media.PhotoPopupFunction;
+import tim.prune.function.media.PlayAudioFunction;
+import tim.prune.function.media.RemoveAudioFunction;
+import tim.prune.function.media.RemovePhotoFunction;
+import tim.prune.function.media.RotatePhoto;
+import tim.prune.function.media.StopAudioFunction;
+import tim.prune.function.search.DownloadOsmFunction;
+import tim.prune.function.search.GetWikipediaFunction;
+import tim.prune.function.search.SearchOsmPoisFunction;
+import tim.prune.function.search.SearchWikipediaNames;
+import tim.prune.function.segments.SplitSegmentsFunction;
 import tim.prune.function.settings.*;
 import tim.prune.function.sew.SewTrackSegmentsFunction;
-import tim.prune.function.sew.SplitSegmentsFunction;
 import tim.prune.function.srtm.LookupSrtmFunction;
 import tim.prune.function.weather.GetWeatherForecastFunction;
 import tim.prune.load.AudioLoader;
@@ -86,6 +84,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_PROJECT_POINT = null;
 	public static GenericFunction FUNCTION_PROJECT_CIRCLE = null;
 	public static GenericFunction FUNCTION_REARRANGE_WAYPOINTS = null;
+	public static GenericFunction FUNCTION_DEDUPE_WAYPOINTS = null;
 	public static GenericFunction FUNCTION_SELECT_SEGMENT = null;
 	public static GenericFunction FUNCTION_SPLIT_SEGMENTS = null;
 	public static GenericFunction FUNCTION_SEW_SEGMENTS = null;
@@ -106,7 +105,6 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_DOWNLOAD_OSM = null;
 	public static GenericFunction FUNCTION_ADD_TIME_OFFSET  = null;
 	public static GenericFunction FUNCTION_ADD_ALTITUDE_OFFSET  = null;
-	public static GenericFunction FUNCTION_CONVERT_NAMES_TO_TIMES  = null;
 	public static GenericFunction FUNCTION_DELETE_FIELD_VALUES  = null;
 	public static GenericFunction FUNCTION_FIND_WAYPOINT = null;
 	public static GenericFunction FUNCTION_TRUNCATE_POINT_COORDS = null;
@@ -121,7 +119,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_PHOTO_POPUP = null;
 	public static GenericFunction FUNCTION_IGNORE_EXIF_THUMB = null;
 	public static GenericFunction FUNCTION_CHARTS = null;
-	public static GenericFunction FUNCTION_3D     = null;
+	public static GenericFunction FUNCTION_3D_VIEW = null;
 	public static GenericFunction FUNCTION_DISTANCES  = null;
 	public static GenericFunction FUNCTION_FULL_DETAILS = null;
 	public static GenericFunction FUNCTION_AUTOPLAY_TRACK = null;
@@ -167,6 +165,7 @@ public abstract class FunctionLibrary
 		FUNCTION_PROJECT_POINT = new ProjectPoint(inApp);
 		FUNCTION_PROJECT_CIRCLE = new ProjectCircle(inApp);
 		FUNCTION_REARRANGE_WAYPOINTS = new RearrangeWaypointsFunction(inApp);
+		FUNCTION_DEDUPE_WAYPOINTS = new DedupeWaypointsFunction(inApp);
 		FUNCTION_SELECT_SEGMENT = new SelectSegmentFunction(inApp);
 		FUNCTION_SPLIT_SEGMENTS = new SplitSegmentsFunction(inApp);
 		FUNCTION_SEW_SEGMENTS = new SewTrackSegmentsFunction(inApp);
@@ -187,7 +186,6 @@ public abstract class FunctionLibrary
 		FUNCTION_DOWNLOAD_OSM = new DownloadOsmFunction(inApp);
 		FUNCTION_ADD_TIME_OFFSET = new AddTimeOffset(inApp);
 		FUNCTION_ADD_ALTITUDE_OFFSET = new AddAltitudeOffset(inApp);
-		FUNCTION_CONVERT_NAMES_TO_TIMES = new ConvertNamesToTimes(inApp);
 		FUNCTION_DELETE_FIELD_VALUES = new DeleteFieldValues(inApp);
 		FUNCTION_FIND_WAYPOINT = new FindWaypoint(inApp);
 		FUNCTION_TRUNCATE_POINT_COORDS = new TruncatePointCoords(inApp);
@@ -201,7 +199,7 @@ public abstract class FunctionLibrary
 		FUNCTION_PHOTO_POPUP = new PhotoPopupFunction(inApp);
 		FUNCTION_IGNORE_EXIF_THUMB = new IgnoreExifThumb(inApp);
 		FUNCTION_CHARTS = new Charter(inApp);
-		FUNCTION_3D     = new ShowThreeDFunction(inApp);
+		FUNCTION_3D_VIEW = new ShowThreeDFunction(inApp);
 		FUNCTION_DISTANCES = new DistanceFunction(inApp);
 		FUNCTION_FULL_DETAILS = new ShowFullDetails(inApp);
 		FUNCTION_AUTOPLAY_TRACK = new AutoplayFunction(inApp);
@@ -223,9 +221,9 @@ public abstract class FunctionLibrary
 		FUNCTION_SET_LANGUAGE = new SetLanguage(inApp);
 		FUNCTION_SET_ALTITUDE_TOLERANCE = new SetAltitudeTolerance(inApp);
 		FUNCTION_SET_TIMEZONE = new SelectTimezoneFunction(inApp);
-		FUNCTION_HELP   = new HelpScreen(inApp);
+		FUNCTION_HELP = new HelpScreen(inApp);
 		FUNCTION_SHOW_KEYS = new ShowKeysScreen(inApp);
-		FUNCTION_ABOUT  = new AboutScreen(inApp);
-		FUNCTION_CHECK_VERSION= new CheckVersionScreen(inApp);
+		FUNCTION_ABOUT = new AboutScreen(inApp);
+		FUNCTION_CHECK_VERSION = new CheckVersionScreen(inApp);
 	}
 }
