@@ -1,6 +1,5 @@
 package tim.prune.data;
 
-import tim.prune.config.Config;
 
 /**
  * Represents a range of altitudes, taking units into account.
@@ -9,7 +8,9 @@ import tim.prune.config.Config;
 public class AltitudeRange
 {
 	/** Range of altitudes in metres */
-	private IntegerRange _range = new IntegerRange();
+	private final IntegerRange _range = new IntegerRange();
+	/** Tolerance value in metres */
+	private final int _wiggleLimit;
 	/** Flag for whether previous value exists or not */
 	private boolean _gotPreviousValue;
 	/** Previous metric value */
@@ -20,22 +21,17 @@ public class AltitudeRange
 	private int _descent;
 	/** Flags for whether minimum or maximum has been found */
 	private boolean _gotPreviousMinimum = false, _gotPreviousMaximum = false;
-	/** Integer values of previous minimum and maximum, if any */
-	private int     _previousExtreme = 0;
+	/** Integer value of previous minimum or maximum, if any */
+	private int _previousExtreme = 0;
 
 
 	/**
 	 * Constructor
+	 * @param toleranceMetres tolerance (wiggle limit) in metres
 	 */
-	public AltitudeRange() {
-		clear();
-	}
-
-	/**
-	 * Clear the altitude range
-	 */
-	public void clear()
+	public AltitudeRange(int toleranceMetres)
 	{
+		_wiggleLimit = toleranceMetres;
 		_range.clear();
 		_climb = _descent = 0;
 		_gotPreviousValue = false;
@@ -51,8 +47,6 @@ public class AltitudeRange
 	 */
 	public void addValue(Altitude inAltitude)
 	{
-		final int wiggleLimit = Config.getConfigInt(Config.KEY_ALTITUDE_TOLERANCE) / 100;
-
 		if (inAltitude != null && inAltitude.isValid())
 		{
 			int altValue = (int) inAltitude.getMetricValue();
@@ -66,7 +60,7 @@ public class AltitudeRange
 					final boolean locallyUp = (altValue > _previousValue);
 					final boolean overallUp = _gotPreviousMinimum && _previousValue > _previousExtreme;
 					final boolean overallDn = _gotPreviousMaximum && _previousValue < _previousExtreme;
-					final boolean moreThanWiggle = Math.abs(altValue - _previousValue) > wiggleLimit;
+					final boolean moreThanWiggle = Math.abs(altValue - _previousValue) > _wiggleLimit;
 					// Do we know whether we're going up or down yet?
 					if (!_gotPreviousMinimum && !_gotPreviousMaximum)
 					{
@@ -117,7 +111,7 @@ public class AltitudeRange
 							_gotPreviousValue = true;
 						}
 					}
-					// TODO: Behaviour when WIGGLE_LIMIT == 0 should be same as before, all differences cumulated
+					// Note: Behaviour when WIGGLE_LIMIT == 0 should be same as before, all differences cumulated
 				}
 			}
 			else
@@ -126,16 +120,6 @@ public class AltitudeRange
 				_previousValue = altValue;
 				_gotPreviousValue = true;
 			}
-
-//			if (!_empty)
-//			{
-//				if (altValue > _previousValue)
-//					_climb += (altValue - _previousValue);
-//				else
-//					_descent += (_previousValue - altValue);
-//			}
-//			_previousValue = altValue;
-//			_empty = false;
 		}
 	}
 
@@ -170,27 +154,25 @@ public class AltitudeRange
 	 */
 	public boolean hasRange()
 	{
-		return _range.getMaximum() > _range.getMinimum();
+		return _range.hasValues();
 	}
 
 
 	/**
 	 * @param inUnit altitude units to use
-	 * @return minimum value, or -1 if none found
+	 * @return minimum value
 	 */
 	public int getMinimum(Unit inUnit)
 	{
-		if (_range.getMinimum() <= 0) return _range.getMinimum();
 		return (int) (_range.getMinimum() * inUnit.getMultFactorFromStd());
 	}
 
 	/**
 	 * @param inUnit altitude units to use
-	 * @return maximum value, or -1 if none found
+	 * @return maximum value
 	 */
 	public int getMaximum(Unit inUnit)
 	{
-		if (_range.getMaximum() <= 0) return _range.getMaximum();
 		return (int) (_range.getMaximum() * inUnit.getMultFactorFromStd());
 	}
 
