@@ -130,19 +130,6 @@ public class DecimalNumberField extends JTextField
 		setText(_localFormatter.format(valueToSet));
 	}
 
-	/**
-	 * @param inValue String value to set, using regular (non-local) formatting
-	 */
-	public void setValue(String inValue)
-	{
-		try {
-			setValue(Double.parseDouble(inValue));
-		}
-		catch (Exception e) {
-			setValue(0.0);
-		}
-	}
-
 	/**
 	 * Put a minimum on the minimum width
 	 */
