@@ -1,9 +1,9 @@
 package tim.prune.gui;
 
 import java.awt.FlowLayout;
+import java.awt.event.KeyAdapter;
+import java.awt.event.KeyEvent;
 import java.awt.BorderLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
 import javax.swing.JDialog;
@@ -13,8 +13,6 @@ import javax.swing.JList;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
 import javax.swing.ListSelectionModel;
-import javax.swing.event.ListSelectionEvent;
-import javax.swing.event.ListSelectionListener;
 
 import tim.prune.App;
 import tim.prune.I18nManager;
@@ -25,8 +23,8 @@ import tim.prune.undo.UndoStack;
  */
 public class UndoManager
 {
-	private App _app = null;
-	private JFrame _parentFrame = null;
+	private final App _app;
+	private final JFrame _parentFrame;
 	private JDialog _dialog = null;
 	private JList<String> _actionList = null;
 
@@ -56,50 +54,43 @@ public class UndoManager
 		mainPanel.add(new JLabel(I18nManager.getText("dialog.undo.pretext")), BorderLayout.NORTH);
 
 		String[] undoActions = new String[undoStack.size()];
-		for (int i=0; i<undoStack.size(); i++)
-		{
+		for (int i=0; i<undoStack.size(); i++) {
 			undoActions[i] = undoStack.getOperationAt(undoStack.size()-1-i).getDescription();
 		}
 		_actionList = new JList<String>(undoActions);
 		_actionList.setSelectionMode(ListSelectionModel.SINGLE_INTERVAL_SELECTION);
 		_actionList.setSelectedIndex(0);
-		_actionList.addListSelectionListener(new ListSelectionListener()
+		_actionList.addListSelectionListener((e) -> {
+			if (_actionList.getMinSelectionIndex() > 0) {
+				_actionList.setSelectionInterval(0, _actionList.getMaxSelectionIndex());
+			}
+		});
+		_actionList.addKeyListener(new KeyAdapter() {
+			public void keyReleased(KeyEvent e)
 			{
-				public void valueChanged(ListSelectionEvent e)
-				{
-					if (_actionList.getMinSelectionIndex() > 0)
-					{
-						_actionList.setSelectionInterval(0, _actionList.getMaxSelectionIndex());
-					}
+				// close dialog if escape pressed
+				if (e.getKeyCode() == KeyEvent.VK_ESCAPE) {
+					_dialog.dispose();
 				}
-			});
+			}
+		});
+
 		mainPanel.add(new JScrollPane(_actionList), BorderLayout.CENTER);
 		// Buttons
 		JPanel buttonPanel = new JPanel();
 		buttonPanel.setLayout(new FlowLayout(FlowLayout.RIGHT));
 		JButton okButton = new JButton(I18nManager.getText("button.ok"));
-		okButton.addActionListener(new ActionListener()
-			{
-				public void actionPerformed(ActionEvent e)
-				{
-					_app.undoActions(_actionList.getMaxSelectionIndex() + 1);
-					_dialog.dispose();
-				}
-			});
+		okButton.addActionListener((e) -> {
+			_app.undoActions(_actionList.getMaxSelectionIndex() + 1);
+			_dialog.dispose();
+		});
 		buttonPanel.add(okButton);
 		JButton cancelButton = new JButton(I18nManager.getText("button.cancel"));
-		cancelButton.addActionListener(new ActionListener()
-			{
-				public void actionPerformed(ActionEvent e)
-				{
-					_dialog.dispose();
-				}
-			});
+		cancelButton.addActionListener((e) -> _dialog.dispose());
 		buttonPanel.add(cancelButton);
 		mainPanel.add(buttonPanel, BorderLayout.SOUTH);
 		_dialog.getContentPane().add(mainPanel);
 		_dialog.pack();
 		_dialog.setVisible(true);
 	}
-
 }
