@@ -4,8 +4,6 @@ import java.awt.BorderLayout;
 import java.awt.Component;
 import java.awt.FlowLayout;
 import java.awt.GridLayout;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.awt.event.KeyAdapter;
 import java.awt.event.KeyEvent;
 
@@ -18,7 +16,6 @@ import javax.swing.JPanel;
 import javax.swing.JProgressBar;
 import javax.swing.JTextField;
 import javax.swing.SwingConstants;
-import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
 import tim.prune.App;
@@ -31,7 +28,7 @@ import tim.prune.load.babel.BabelFilterPanel;
 /**
  * Class to manage the loading of data from a GPS device using GpsBabel
  */
-public class BabelLoadFromGps extends BabelLoader
+public class BabelLoadFromGps extends BabelLoadFunction
 {
 	// Text fields for entering device and format
 	private JTextField _deviceField = null, _formatField = null;
@@ -71,9 +68,10 @@ public class BabelLoadFromGps extends BabelLoader
 	}
 
 	/**
+	 * @param inOkButton ok button
 	 * @return a panel containing the main dialog components
 	 */
-	protected JPanel makeDialogComponents()
+	protected JPanel makeDialogComponents(JButton inOkButton)
 	{
 		JPanel outerPanel = new JPanel();
 		outerPanel.setLayout(new BorderLayout());
@@ -110,12 +108,7 @@ public class BabelLoadFromGps extends BabelLoader
 		mainPanel.add(gridPanel);
 
 		// checkboxes
-		ChangeListener checkboxListener = new ChangeListener() {
-			public void stateChanged(ChangeEvent e)
-			{
-				enableOkButton();
-			}
-		};
+		ChangeListener checkboxListener = e -> enableOkButton();
 		_waypointCheckbox = new JCheckBox(I18nManager.getText("dialog.gpsload.getwaypoints"), true);
 		_waypointCheckbox.addChangeListener(checkboxListener);
 		_waypointCheckbox.setAlignmentX(Component.CENTER_ALIGNMENT);
@@ -146,26 +139,13 @@ public class BabelLoadFromGps extends BabelLoader
 		// Lower panel with ok and cancel buttons
 		JPanel buttonPanel = new JPanel();
 		buttonPanel.setLayout(new FlowLayout(FlowLayout.RIGHT));
-		_okButton = new JButton(I18nManager.getText("button.ok"));
-		ActionListener okListener = new ActionListener() {
-			public void actionPerformed(ActionEvent e)
-			{
-				// start thread to call gpsbabel
-				_cancelled = false;
-				new Thread(BabelLoadFromGps.this).start();
-			}
-		};
-		_okButton.addActionListener(okListener);
-		_deviceField.addActionListener(okListener);
-		_formatField.addActionListener(okListener);
-		buttonPanel.add(_okButton);
+		_deviceField.addActionListener((e) -> okPressed());
+		_formatField.addActionListener((e) -> okPressed());
+		buttonPanel.add(inOkButton);
 		JButton cancelButton = new JButton(I18nManager.getText("button.cancel"));
-		cancelButton.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e)
-			{
-				_cancelled = true;
-				_dialog.dispose();
-			}
+		cancelButton.addActionListener(e -> {
+			_cancelled = true;
+			_dialog.dispose();
 		});
 		buttonPanel.add(cancelButton);
 		outerPanel.add(buttonPanel, BorderLayout.SOUTH);
