@@ -24,13 +24,10 @@ public abstract class FilterDefinition extends JPanel
 	public FilterDefinition(AddFilterDialog inFilterDialog)
 	{
 		_parentDialog = inFilterDialog;
-		_paramChangeListener = new KeyAdapter() {
+		_paramChangeListener = new KeyAdapter()
+		{
 			public void keyTyped(KeyEvent arg0) {
-				SwingUtilities.invokeLater(new Runnable() {
-					public void run() {
-						_parentDialog.filterParamsChanged();
-					}
-				});
+				SwingUtilities.invokeLater(() -> _parentDialog.filterParamsChanged());
 			}
 		};
 	}
@@ -43,8 +40,7 @@ public abstract class FilterDefinition extends JPanel
 	/**
 	 * @return filter definition to pass to gpsbabel
 	 */
-	public String getString()
-	{
+	public String getString() {
 		return "-x " + getFilterName() + getParameters();
 	}
 
