@@ -1,11 +1,12 @@
 package tim.prune.load.xml;
 
-import java.io.File;
 import java.io.FileInputStream;
 import java.util.zip.GZIPInputStream;
 import tim.prune.App;
 import tim.prune.I18nManager;
 import tim.prune.data.SourceInfo;
+import tim.prune.load.FileToBeLoaded;
+import tim.prune.load.FileTypeLoader;
 import tim.prune.load.MediaLinkInfo;
 
 /**
@@ -31,14 +32,13 @@ public class GzipFileLoader
 
 	/**
 	 * Open the selected file and select appropriate xml loader
-	 * @param inFile File to open
+	 * @param inFileLock File to open
+	 * @param inAutoAppend true to auto-append
 	 */
-	public void openFile(File inFile)
+	public void openFile(FileToBeLoaded inFileLock, boolean inAutoAppend)
 	{
-		GZIPInputStream istream = null;
-		try
+		try (GZIPInputStream istream = new GZIPInputStream(new FileInputStream(inFileLock.getFile())))
 		{
-			istream = new GZIPInputStream(new FileInputStream(inFile));
 			_xmlLoader.reset();
 			// Parse the stream using either Xerces or java classes
 			_xmlLoader.parseXmlStream(istream);
@@ -49,11 +49,10 @@ public class GzipFileLoader
 			else
 			{
 				// Send back to app
-				SourceInfo sourceInfo = new SourceInfo(inFile,
-					(handler instanceof GpxHandler?SourceInfo.FILE_TYPE.GPX:SourceInfo.FILE_TYPE.KML));
-				_app.informDataLoaded(handler.getFieldArray(), handler.getDataArray(),
-					null, sourceInfo, handler.getTrackNameList(),
-					new MediaLinkInfo(inFile, handler.getLinkArray()));
+				SourceInfo sourceInfo = new SourceInfo(inFileLock.getFile(),
+					(handler instanceof GpxHandler ? SourceInfo.FILE_TYPE.GPX : SourceInfo.FILE_TYPE.KML));
+				new FileTypeLoader(_app).loadData(handler, sourceInfo, inAutoAppend,
+					new MediaLinkInfo(inFileLock.getFile(), handler.getLinkArray()));
 			}
 		}
 		catch (Exception e)
@@ -64,11 +63,5 @@ public class GzipFileLoader
 			// It would be nice to verify the filename of the file inside the gz,
 			// but the java classes don't give access to this information
 		}
-		finally {
-			try {
-				istream.close();
-			}
-			catch (Exception e2) {}
-		}
 	}
 }
