@@ -3,7 +3,6 @@ package tim.prune.load.xml;
 import org.xml.sax.helpers.DefaultHandler;
 
 import tim.prune.data.Field;
-import tim.prune.load.TrackNameList;
 
 /**
  * Abstract superclass of xml handlers
@@ -21,14 +20,6 @@ public abstract class XmlHandler extends DefaultHandler
 	 */
 	public abstract Field[] getFieldArray();
 
-	/**
-	 * Can be overridden (eg by gpx handler) to provide a track name list
-	 * @return track name list object if any, or null
-	 */
-	public TrackNameList getTrackNameList() {
-		return null;
-	}
-
 	/**
 	 * Can be overridden (eg by gpx handler) to provide an array of links to media
 	 * @return array of Strings if any, or null
