@@ -16,7 +16,6 @@ public interface UndoOperation
 	/**
 	 * Perform the undo operation on the specified track
 	 * @param inTrackInfo TrackInfo object on which to perform the operation
-	 * @throws UndoException when undo fails
 	 */
-	public void performUndo(TrackInfo inTrackInfo) throws UndoException;
+	public void performUndo(TrackInfo inTrackInfo);
 }
\ No newline at end of file
